"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const plugin_1 = require("@stryker-mutator/api/plugin");
const copy_1 = require("./helpers/copy");
const tokens_1 = require("./helpers/tokens");
class JavaScriptMutator {
    constructor(log, mutators, parser) {
        this.log = log;
        this.mutators = mutators;
        this.parser = parser;
    }
    mutate(inputFiles) {
        const mutants = [];
        inputFiles.forEach(file => {
            const ast = this.parser.parse(file.textContent);
            this.parser.getNodes(ast).forEach(node => {
                this.mutators.forEach(mutator => {
                    const mutatedNodes = mutator.mutate(node, copy_1.default);
                    if (mutatedNodes) {
                        const newMutants = this.generateMutants(mutatedNodes, mutator.name, file.name);
                        mutants.push(...newMutants);
                    }
                });
            });
        });
        return mutants;
    }
    generateMutants(mutatedNodes, mutatorName, fileName) {
        const mutants = [];
        mutatedNodes.forEach(node => {
            const replacement = this.parser.generateCode(node);
            if (node.start !== null && node.end !== null) {
                const range = [node.start, node.end];
                const mutant = {
                    fileName,
                    mutatorName,
                    range,
                    replacement
                };
                this.log.trace(`Generated mutant for mutator ${mutatorName} in file ${fileName} with replacement code "${replacement}"`);
                mutants.push(mutant);
            }
        });
        return mutants;
    }
}
exports.JavaScriptMutator = JavaScriptMutator;
JavaScriptMutator.inject = plugin_1.tokens(plugin_1.commonTokens.logger, tokens_1.NODE_MUTATORS_TOKEN, tokens_1.PARSER_TOKEN);
//# sourceMappingURL=JavaScriptMutator.js.map