"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const types = require("@babel/types");
const NodeGenerator_1 = require("../helpers/NodeGenerator");
/**
 * Represents a mutator which can remove the conditional clause from statements.
 */
class ConditionalExpressionMutator {
    constructor() {
        this.validOperators = ['!=', '!==', '&&', '<', '<=', '==', '===', '>', '>=', '||'];
        this.name = 'ConditionalExpression';
    }
    hasValidParent(node) {
        return (!node.parent ||
            !(types.isForStatement(node.parent) ||
                types.isWhileStatement(node.parent) ||
                types.isIfStatement(node.parent) ||
                types.isDoWhileStatement(node.parent)));
    }
    isValidOperator(operator) {
        return this.validOperators.includes(operator);
    }
    mutate(node) {
        if ((types.isBinaryExpression(node) || types.isLogicalExpression(node)) && this.hasValidParent(node) && this.isValidOperator(node.operator)) {
            return [NodeGenerator_1.NodeGenerator.createBooleanLiteralNode(node, false), NodeGenerator_1.NodeGenerator.createBooleanLiteralNode(node, true)];
        }
    }
}
exports.default = ConditionalExpressionMutator;
//# sourceMappingURL=ConditionalExpressionMutator.js.map